@@ -23,9 +23,9 @@
 
    /* first libmilter version that has MDS support */
 #  define SMFI_VERSION_MDS	0x01000002
-# else /* _FFR_MDS_NEGOTIATE */
+# else
 #  define SMFI_VERSION	0x01000001	/* libmilter version number */
-# endif /* _FFR_MDS_NEGOTIATE */
+# endif
 #endif /* ! SMFI_VERSION */
 
 #define SM_LM_VRS_MAJOR(v)	(((v) & 0x7f000000) >> 24)
@@ -476,7 +476,7 @@ LIBMILTER_API int smfi_insheader __P((SMFICTX *, int, char *, char *));
 **  as a result of adding this header.
 **
 **	SMFICTX *ctx; Opaque context structure
-**  	int idx; index into the header list where the insertion should happen
+**	int idx; index into the header list where the insertion should happen
 **	char *headerh; Header field name
 **	char *headerv; Header field value
 */
